@@ -24,7 +24,7 @@ use Object::Tiny qw(
 );
 
 use vars '$VERSION';
-$VERSION = '0.50';
+$VERSION = '0.51';
 
 sub go {
     my $class = shift;
@@ -1024,6 +1024,11 @@ Returns the value passed for the C<verbose> parameter to C<new()>. Defaults to
 
 Add support for resizing the nav pane.
 
+=item *
+
+Allow right and middle clicks on nav window links to copy links or open them
+in a new Window (L<Issue #1|http://github.com/theory/pod-site/issues/1>).
+
 =back
 
 This module is stored in an open L<GitHub
@@ -1032,6 +1037,13 @@ contribute!
 
 Found a bug? Please L<file a report|http://github.com/theory/pod-site/issues>!
 
+=head1 Support
+
+This module is stored in an open GitHub repository,
+L<http://github.com/theory/pod-site/>. Feel free to fork and contribute!
+
+Please file bug reports at L<http://github.com/theory/pod-site/issues/>.
+
 =head1 Author
 
 David E. Wheeler <david@justatheory.com>
